@@ -7,6 +7,7 @@ from __future__ import absolute_import
 
 import re
 import operator
+import io
 
 __all__ = [
     'Rake',
@@ -63,7 +64,7 @@ def RanksNLStoplist():
 
 
 def load_stop_words(stop_word_file, regex):
-    with open(stop_word_file, encoding='utf8') as stop_word_file:
+    with io.open(stop_word_file, encoding='utf8') as stop_word_file:
         stop_words = re.split(regex, stop_word_file.read())
     return [word for word in stop_words if word not in ('', ' ')]  # filters empty string matches
 
@@ -74,7 +75,7 @@ def separate_words(text):
     @param text The text that must be split in to words.
     @param min_word_return_size The minimum no of characters a word must have to be included.
     """
-    splitter = re.compile('(?u)\W+')
+    splitter = re.compile(r'(?u)\W+')
     words = []
     for single_word in splitter.split(text):
         current_word = single_word.strip().lower()
@@ -152,7 +153,7 @@ def generate_candidate_keyword_scores(phrase_list, word_score, minFrequency):
 
 class Rake(object):
 
-    def __init__(self, stop_words, regex='[\W\n]+'):
+    def __init__(self, stop_words, regex=r'[\W\n]+'):
         #lets users call predefined stopwords easily in a platform agnostic manner or use their own list
         if isinstance(stop_words, list):
             self.__stop_words_pattern = build_stop_word_regex(stop_words)
